@@ -16,7 +16,7 @@ class DefaultRegister(Register):
             return False
         return self.data == o.data
 
-    def read(self, file: IO, storage: str = "") -> bool:
+    def read(self, file: IO, storage: str = "", *args, **kwargs) -> bool:
         """
         Generic function to perform the reading of the register using
         a filepointer.
@@ -32,7 +32,7 @@ class DefaultRegister(Register):
             self.data = None
         return True
 
-    def write(self, file: IO, storage: str = "") -> bool:
+    def write(self, file: IO, storage: str = "", *args, **kwargs) -> bool:
         """
         Generic function to perform the writing of the register using
         a filepointer.
