@@ -1,10 +1,10 @@
-from typing import Any, List, Optional
+from typing import Any, List, Optional, Union
 
 from cfinterface.components.field import Field
 
-from cfinterface.adapters.line.repository import Repository
-from cfinterface.adapters.line.positionalrepository import PositionalRepository
-from cfinterface.adapters.line.delimitedrepository import DelimitedRepository
+from cfinterface.adapters.components.line.repository import (
+    factory,
+)
 
 
 class Line:
@@ -17,28 +17,32 @@ class Line:
         self,
         fields: List[Field],
         values: Optional[List[Any]] = None,
-        delimiter: Optional[str] = None,
+        delimiter: Optional[Union[str, bytes]] = None,
+        storage: str = "",
     ):
         self._delimiter = delimiter
-        self._repository: Repository = None  # type: ignore
-        if delimiter is None:
-            self._repository = PositionalRepository(fields, values)
-        else:
-            self._repository = DelimitedRepository(fields, values, delimiter)
+        self._fields = fields
+        self._values = values
+        self._storage = storage
+        self.__generate_repository()
+        self._size = sum([f.size for f in fields])
 
-    def read(self, line: str) -> List[Any]:
+    def __generate_repository(self):
+        self._repository = factory(self._storage)(self._fields, self._values)
+
+    def read(self, line: Union[str, bytes]) -> List[Any]:
         """
         Reads a line for extracting information following
         the given fields.
 
         :param line: The line to be read
-        :type line: str
+        :type line: str | bytes
         :return: The extracted values, in order
         :rtype: List[Any]
         """
-        return self._repository.read(line)
+        return self._repository.read(line, self._delimiter)
 
-    def write(self, values: List[Any]) -> str:
+    def write(self, values: List[Any]) -> Union[str, bytes]:
         """
         Writes to a line with the existing information
         in the given fields.
@@ -46,9 +50,9 @@ class Line:
         :param values: The value of the fields to be written
         :type line: List[Any]
         :return: The line with the new field information
-        :rtype: str
+        :rtype: str | bytes
         """
-        return self._repository.write(values)
+        return self._repository.write(values, self._delimiter)
 
     @property
     def fields(self) -> List[Field]:
@@ -67,9 +71,22 @@ class Line:
         self._repository.values = vals
 
     @property
-    def delimiter(self) -> Optional[str]:
+    def delimiter(self) -> Optional[Union[str, bytes]]:
         return self._delimiter
 
     @delimiter.setter
-    def delimiter(self, d: Optional[str]):
+    def delimiter(self, d: Optional[Union[str, bytes]]):
         self._delimiter = d
+
+    @property
+    def storage(self) -> str:
+        return self._storage
+
+    @storage.setter
+    def storage(self, s: str):
+        self._storage = s
+        self.__generate_repository()
+
+    @property
+    def size(self) -> int:
+        return self._size
