@@ -17,16 +17,18 @@ class BlockWriting:
         self.__storage = storage
         self.__repository: Repository = None  # type: ignore
 
-    def __write_file(self):
+    def __write_file(self, *args, **kwargs):
         """
         Writes all the blocks from the given BlockData structure
         to the specified file.
 
         """
         for b in self.__data:
-            b.write(self.__repository.file)
+            b.write(self.__repository.file, *args, **kwargs)
 
-    def write(self, filename: str, directory: str, encoding: str):
+    def write(
+        self, filename: str, directory: str, encoding: str, *args, **kwargs
+    ):
         """
         Writes a file with a given name in a given directory with
         the data from the BlockData structure.
@@ -41,7 +43,7 @@ class BlockWriting:
         filepath = join(directory, filename)
         self.__repository = factory(self.__storage)(filepath, encoding)
         with self.__repository:
-            return self.__write_file()
+            return self.__write_file(*args, **kwargs)
 
     @property
     def data(self) -> BlockData:
